@@ -1331,7 +1331,7 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
 # in perl:
 #     - convolution with nehomogenities
 #     - analyse range
-#     - gpressTAB  STD    my $densNEW=$densSTD  *  $p/1013.25  *   273.15/$T;
+#     - gpressTAB  STD    my $densNEW=$densSTD  *  $p/101.325  *   273.15/$T;
 #     -   if ( $args{"fthick"} >0){           amoeba
 
 
@@ -1433,7 +1433,7 @@ def isitGas( material ):
 # get_thick_rho  ......  I extract the part
 #         return   thick [ug/cm2] and rho g/cm3
 #####################################
-def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):   #convert properly um and find rho
+def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #convert properly um and find rho
     """
     takes all thicknesses   um  ug:
 
@@ -1467,21 +1467,21 @@ def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):
         """
         trim assumes the target as STP before 1982
         T=273.15 K
-        p=1013.25 kPa
+        p=101.325 kPa           =>>>>     p=101.325 kPa   10^5 !!!!!
         SRIMHelp/helpTR23.rtf
         """
-        R=1013.25e+3/273.15/rho
+        R=101.325e+3/273.15/rho
         rho2=Pressure/R/Temperature
-        print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+        print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     elif material.title() in elements:
         #print("D... rho - elements")
         eZ=elements.index(material.title())
         print("D... rho - elements  eZ={:d}".format(eZ))
         #print(gas)
         if gas[ eZ ]==1:
-            R=1013.25e+3/273.15/rho
+            R=101.325e+3/273.15/rho
             rho2=Pressure/R/Temperature
-            print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+            print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     else: # could be also a gaseous  isotope
         #print('D... maybe gaseous isotope?')
         if isotope is None:
@@ -1497,9 +1497,9 @@ def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):
             eZ=isotope.Z
             if gas[ eZ ]==1:
                 print('i... GAS')
-                R=1013.25e+3/273.15/rho
+                R=101.325e+3/273.15/rho
                 rho2=Pressure/R/Temperature
-                print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+                print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     rho=rho2
     #print("D... rho WAS deduced")
     # THICKNESS TO mgcm2:    ##### MY UNIT WILL BE mg/cm2
@@ -1550,7 +1550,7 @@ def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):
 #
 #            prasarna  ......... incomming0
 ########################################
-def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number, Pressure=1013250, Temperature=273):
+def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number, Pressure=101325, Temperature=273):
     '''
     Here I prepare materials:  single layers
     '''
@@ -1571,20 +1571,20 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
         """
         trim assumes the target as STP before 1982
         T=273.15 K
-        p=1013.25 kPa
+        p=101.325 kPa
         SRIMHelp/helpTR23.rtf
         """
-        R=1013.25e+3/273.15/rho
+        R=101.325e+3/273.15/rho
         rho2=Pressure/R/Temperature
-        print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+        print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     elif material.title() in elements:
         print("D... rho - elements")
         eZ=elements.index(material.title())
         print("D... rho - elements  eZ=",eZ)
         if gaseous[ eZ ]==1:
-            R=1013.25e+3/273.15/rho
+            R=101.325e+3/273.15/rho
             rho2=Pressure/R/Temperature
-            print('i...rho at STD (0deg,1013kPa)=',rho,' now=',rho2)
+            print('i...rho at STD (0deg,101.3kPa)=',rho,' now=',rho2)
     else: # could be also a gaseous  isotope
         #print('D... maybe gaseous isotope?')
         try:
@@ -1597,9 +1597,9 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
             eZ=isotope.Z
             if gaseous[ eZ ]==1:
                 print('i... GAS')
-                R=1013.25e+3/273.15/rho
+                R=101.325e+3/273.15/rho
                 rho2=Pressure/R/Temperature
-                print('i...rho at STD (0deg,1013kPa)=',rho,' now=',rho2)
+                print('i...rho at STD (0deg,101.3kPa)=',rho,' now=',rho2)
     rho=rho2
 
     #print("DDD... rho deduced")============================================
@@ -1644,7 +1644,7 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
 
 #--------------------------------------------------- START OF OLD NUPHY BIN
 def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness="0ug",
-                  material="c12", Pressure=1013.25e+3, Temperature=273.15,
+                  material="c12", Pressure=101.325e+3, Temperature=273.15,
                   silent = False, fwhm=0, Store="" ):
 
     #print("1=============/{}/==========".format(Store))
@@ -1978,7 +1978,7 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
 def main( i="", m="" , t="", e="", a="",  n=100,
           dens=0,              # override density
           f=0,                 # fwhm of the detector
-          p=1013.25, k=273.15, #k =temp in K
+          p=101325, k=273.15, #k =temp in K
 #          h="",                #
           w="",
           s = False,           # silent
